@@ -3,14 +3,14 @@ from typing import Optional
 
 import click
 
-from .main import convert_csv_to_insert_statement
+from .main import convert_table_file_to_insert_statement
 
 logger = logging.getLogger()
 
 
 @click.command()
 @click.argument(
-    "filename",
+    "path-to-file",
     type=str,
 )
 @click.option(
@@ -27,20 +27,20 @@ logger = logging.getLogger()
 )
 @click.option("--output-file", default=None, help="Name of file to write SQL insert to")
 def cli(
-    filename: str,
+    path_to_file: str,
     output_table: str,
     delimiter: Optional[str],
     has_types_row: Optional[bool],
     output_file: Optional[str],
 ):
     """Converts given table file to SQL insert statements."""
-    file_extension = filename.split(".")[-1]
-    if file_extension == "csv":
-        insert_statement = convert_csv_to_insert_statement(
-            filename, output_table=output_table, delimiter=delimiter, types_row=has_types_row
-        )
-    else:
-        raise NotImplementedError(f"'.{file_extension}' file extension is not supported")
+
+    insert_statement = convert_table_file_to_insert_statement(
+        path_to_file=path_to_file,
+        output_table=output_table,
+        delimiter=delimiter,
+        has_types_row=has_types_row,
+    )
 
     print(insert_statement)
     if output_file:
